@@ -1208,8 +1208,8 @@ shell::pid_t shell::spawn(const char *path, char **argv, char **envp, fd_t *stdi
 
 exit:
     if(ep)
-        delete ep;
-    delete args;
+        delete[] ep;
+    delete[] args;
     for(pos = 0; pos < 3; ++pos) {
         if(dups[pos] != INVALID_HANDLE_VALUE)
             CloseHandle(dups[pos]);
@@ -1255,7 +1255,8 @@ void shell::detach(mainproc_t entry)
     if(_domain)
         name = _domain;
 
-    name = strdup(name);
+    // detach only called once, keeps persistent name...
+    name = ::strdup(name);
 
     if(entry == NULL)
         return;
@@ -1364,8 +1365,8 @@ int shell::detach(const char *path, char **argv, char **envp, fd_t *stdio)
 
 exit:
     if(ep)
-        delete ep;
-    delete args;
+        delete[] ep;
+    delete[] args;
     for(pos = 0; pos < 3; ++pos) {
         if(dups[pos] != INVALID_HANDLE_VALUE)
             CloseHandle(dups[pos]);
@@ -1855,7 +1856,8 @@ void shell::release(int exit_code)
 #endif
     if(dev && *dev) {
         fd = open(dev, O_RDWR);
-        if(fd > 0)
+        //fixme: for later review...
+        if(fd != 0)
             dup2(fd, 0);
         if(fd != 1)
             dup2(fd, 1);
