@@ -407,18 +407,18 @@ protected:
      * a "tell" offset.
      * @return offset of input buffer.
      */
-    inline size_t input_pending(void)
+    inline size_t input_pending(void) const
         {return bufpos;}
 
     /**
      * Get current output position.  Sometimes used to help compute a
      * "trunc" operation.
      */
-    inline size_t output_waiting(void)
+    inline size_t output_waiting(void) const
         {return outsize;}
 
 public:
-    const char *endl(void)
+    const char *endl(void) const
         {return eol;}
 
     /**
@@ -473,35 +473,35 @@ public:
      * See if buffer open.
      * @return true if buffer active.
      */
-    inline operator bool()
+    inline operator bool() const
         {return buffer != NULL;}
 
     /**
      * See if buffer closed.
      * @return true if buffer inactive.
      */
-    inline bool operator!()
+    inline bool operator!() const
         {return buffer == NULL;}
 
     /**
      * See if buffer open.
      * @return true if buffer active.
      */
-    inline bool is_open(void)
+    inline bool is_open(void) const
         {return buffer != NULL;}
 
     /**
      * See if input active.
      * @return true if input active.
      */
-    inline bool is_input(void)
+    inline bool is_input(void) const
         {return input != NULL;}
 
     /**
      * See if output active.
      * @return true if output active.
      */
-    inline bool is_output(void)
+    inline bool is_output(void) const
         {return output != NULL;}
 
     /**
@@ -517,7 +517,7 @@ public:
     inline void seteof(void)
         {end = true;}
 
-    inline int err(void)
+    inline int err(void) const
         {return _err();}
 
     template<typename T> inline size_t write(const T& data)
@@ -593,7 +593,7 @@ protected:
     /**
      * Buffer of key value.
      */
-    virtual void *keydata(void) const = 0;
+    virtual const void *keydata(void) const = 0;
 
     virtual bool equal(const KeyProtocol& compare) const;
 
