@@ -89,14 +89,14 @@ private:
     friend class ConditionalAccess;
 
 #if defined(_MSCONDITIONAL_)
-    CRITICAL_SECTION mutex;
-    CONDITION_VARIABLE cond;
+    mutable CRITICAL_SECTION mutex;
+    mutable CONDITION_VARIABLE cond;
 #elif defined(_MSTHREADS_)
     enum {SIGNAL = 0, BROADCAST = 1};
     HANDLE events[2];
     unsigned waiting;
-    CRITICAL_SECTION mlock;
-    CRITICAL_SECTION mutex;
+    mutable CRITICAL_SECTION mlock;
+    mutable CRITICAL_SECTION mutex;
 #else
 #ifndef __PTH__
     class __LOCAL attribute
@@ -109,8 +109,8 @@ private:
     __LOCAL static attribute attr;
 #endif
 
-    pthread_cond_t cond;
-    pthread_mutex_t mutex;
+    mutable pthread_cond_t cond;
+    mutable pthread_mutex_t mutex;
 #endif
 
 protected:
@@ -184,6 +184,36 @@ protected:
     ~Conditional();
 
 public:
+    friend class autolock;
+
+    class __EXPORT autolock
+    {
+    private:
+#ifdef  _MSTHREADS_
+        CRITICAL_SECTION *mutex;
+#else
+        pthread_mutex_t *mutex;
+#endif
+
+    public:
+        inline autolock(const Conditional* object) {
+            mutex = &object->mutex;
+#ifdef _MSTHREADS_
+            EnterCriticalSection(mutex);
+#else
+            pthread_mutex_lock(mutex);
+#endif
+        }
+
+        inline ~autolock() {
+#ifdef  _MSTHREADS_
+            LeaveCriticalSection(mutex);
+#else
+            pthread_mutex_unlock(mutex);
+#endif
+        }
+    };
+
 #if !defined(_MSTHREADS_) && !defined(__PTH__)
     /**
      * Support function for getting conditional attributes for realtime
@@ -216,7 +246,7 @@ protected:
 #if defined _MSCONDITIONAL_
     CONDITION_VARIABLE bcast;
 #elif !defined(_MSTHREADS_)
-    pthread_cond_t bcast;
+    mutable pthread_cond_t bcast;
 #endif
 
     unsigned pending, waiting, sharing;
@@ -368,10 +398,10 @@ private:
 #ifdef _MSTHREADS_
     HANDLE event;
 #else
-    pthread_cond_t cond;
+    mutable pthread_cond_t cond;
     bool signalled;
 #endif
-    pthread_mutex_t mutex;
+    mutable pthread_mutex_t mutex;
 
 protected:
     /**
@@ -657,7 +687,7 @@ public:
      * Release an arbitrary object that has been protected by a rwlock.
      * @param object to release.
      */
-    static void release(const void *object);
+    static bool release(const void *object);
 
     /**
      * Release the lock.
@@ -927,12 +957,30 @@ public:
 class __EXPORT Mutex : public ExclusiveAccess
 {
 protected:
-    pthread_mutex_t mlock;
+    mutable pthread_mutex_t mlock;
 
     virtual void _lock(void);
     virtual void _unlock(void);
 
 public:
+    friend class autolock;
+
+    class __EXPORT autolock
+    {
+    private:
+        pthread_mutex_t *mutex;
+
+    public:
+        inline autolock(const Mutex *object) {
+            mutex = &object->mlock;
+            pthread_mutex_lock(this->mutex);
+        }
+
+        inline ~autolock() {
+            pthread_mutex_unlock(this->mutex);
+        }
+    };
+
     /**
      * Guard class to apply scope based mutex locking to objects.  The mutex
      * is located from the mutex pool rather than contained in the target
@@ -1046,13 +1094,13 @@ public:
      * dynamically managed mutex.
      * @param pointer to protect.
      */
-    static void protect(const void *pointer);
+    static bool protect(const void *pointer);
 
     /**
      * Specify a pointer/object/resource to release.
      * @param pointer to release.
      */
-    static void release(const void *pointer);
+    static bool release(const void *pointer);
 };
 
 /**
@@ -1130,7 +1178,7 @@ class __EXPORT LockedPointer
 {
 private:
     friend class locked_release;
-    pthread_mutex_t mutex;
+    mutable pthread_mutex_t mutex;
     ObjectProtocol *pointer;
 
 protected:
@@ -1274,7 +1322,7 @@ protected:
     /**
      * Check if running.
      */
-    virtual bool is_active(void);
+    virtual bool is_active(void) const;
 
 public:
     /**
@@ -1357,13 +1405,13 @@ public:
      */
     static pthread_t self(void);
 
-    inline operator bool()
+    inline operator bool() const
         {return is_active();}
 
-    inline bool operator!()
+    inline bool operator!() const
         {return !is_active();}
 
-    inline bool isRunning(void)
+    inline bool isRunning(void) const
         {return is_active();}
 };
 
@@ -1406,7 +1454,7 @@ protected:
      */
     void join(void);
 
-    bool is_active(void);
+    bool is_active(void) const;
 
     virtual void run(void) = 0;
 
@@ -1465,7 +1513,7 @@ protected:
      */
     void exit(void);
 
-    bool is_active(void);
+    bool is_active(void) const;
 
     virtual void run(void) = 0;
 
@@ -2015,48 +2063,13 @@ inline void lock(rexlock_t &lock)
 inline void release(rexlock_t &lock)
     {lock.release();}
 
-inline bool _sync_protect_(const void *obj)
-{
-    Mutex::protect(obj);
-    return true;
-}
+#define __AUTOLOCK__    autolock __autolock__(this);
 
-inline bool _sync_release_(const void *obj)
-{
-    Mutex::release(obj);
-    return false;
-}
+#define __SYNC__ for(bool _sync_flag_ = Mutex::protect(this); _sync_flag_; _sync_flag_ = !Mutex::release(this))
 
-inline bool _rw_reader_(const void *obj)
-{
-    ThreadLock::reader(obj);
-    return true;
-}
+#define __SHARED__ for(bool _sync_flag_ = ThreadLock::reader(this); _sync_flag_; _sync_flag_ = !ThreadLock::release(this))
 
-inline bool _rw_writer_(const void *obj)
-{
-    ThreadLock::writer(obj);
-    return true;
-}
-
-inline bool _rw_release_(const void *obj)
-{
-    ThreadLock::release(obj);
-    return false;
-}
-
-#define ENTER_EXCLUSIVE \
-    do { static pthread_mutex_t __sync__ = PTHREAD_MUTEX_INITIALIZER; \
-        pthread_mutex_lock(&__sync__);
-
-#define LEAVE_EXCLUSIVE \
-    pthread_mutex_unlock(&__sync__);} while(0);
-
-#define SYNC(obj) for(bool _sync_flag_ = _sync_protect_(obj); _sync_flag_; _sync_flag_ = _sync_release_(obj))
-
-#define SHARED(obj) for(bool _sync_flag_ = _rw_reader_(obj); _sync_flag_; _sync_flag_ = _rw_release_(obj))
-
-#define EXCLUSIVE(obj) for(bool _sync_flag_ = _rw_writer_(obj); _sync_flag_; _sync_flag_ = _rw_release_(obj))
+#define ___EXCLUSIVE__ for(bool _sync_flag_ = ThreadLock::writer(this); _sync_flag_; _sync_flag_ = !ThreadLock::release(this))
 
 } // namespace ucommon
 
