@@ -15,6 +15,10 @@
 // You should have received a copy of the GNU Lesser General Public License
 // along with GNU uCommon C++.  If not, see <http://www.gnu.org/licenses/>.
 
+#ifdef __APPLE__
+#pragma clang diagnostic ignored "-Wdeprecated-declarations"
+#endif
+
 #include <ucommon-config.h>
 #include <ucommon/ucommon.h>
 #include <ucommon/export.h>
